@@ -40,3 +40,15 @@ def simplify_graphml(graphpath, directed=True, simplify=True):
     return g
 
 ##########################################################
+def plot_graph(g, plotpath, shppath=''):
+    """Plot the graph @g and export to @plotpath and, if provided, plot
+    the border given by @shppath"""
+    vcoords = np.array([(x, y) for x, y in zip(g.vs['x'], g.vs['y'])])
+
+    ecoords = []
+    for e in g.es:
+        ecoords.append([ [float(g.vs[e.source]['x']), float(g.vs[e.source]['y'])],
+                [float(g.vs[e.target]['x']), float(g.vs[e.target]['y'])], ])
+
+    import plot
+    plot.plot_graph(vcoords, ecoords, plotpath, shppath)
