@@ -60,3 +60,23 @@ def create_meshgrid(x, y, nx=100, ny=100, relmargin=.1):
     xx, yy = np.mgrid[xrange[0]:xrange[1]:(nx*1j), yrange[0]:yrange[1]:(ny*1j)]
     return xx, yy, dx, dy
 
+#############################################################
+def plot_graph(vcoords, ecoords, plotpath, shppath=''):
+    """Plot the grpah, with vertices colored by accessibility."""
+    info(inspect.stack()[0][3] + '()')
+
+    fig, ax = plt.subplots(figsize=(7, 7))
+
+    sc = ax.scatter(vcoords[:, 0], vcoords[:, 1], c='k',
+            linewidths=0, alpha=.8, s=3, zorder=10) # vertices
+
+    segs = LineCollection(ecoords, colors='k', linewidths=.5, alpha=.5) # edges
+    ax.add_collection(segs)
+
+    if shppath: # border
+        mapx, mapy = get_shp_points(shppath)
+        ax.plot(mapx, mapy, c='dimgray')
+
+    ax.axis('off')
+    plt.tight_layout()
+    plt.savefig(plotpath)
